summaryrefslogtreecommitdiffstats
path: root/src/notecontent.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/notecontent.cpp')
-rw-r--r--src/notecontent.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/notecontent.cpp b/src/notecontent.cpp
index 4ba09d1..02fc97a 100644
--- a/src/notecontent.cpp
+++ b/src/notecontent.cpp
@@ -138,7 +138,7 @@ void NoteContent::contentChanged(int newMinWidth)
m_minWidth = newMinWidth;
if (note()) {
// note()->unbufferize();
- note()->requestRetqlayout(); // TODO: It should re-set the width! m_width = 0 ? contentChanged: setWidth, geteight, if size havent changed, only repaint and not retqlayout
+ note()->requestRelayout(); // TODO: It should re-set the width! m_width = 0 ? contentChanged: setWidth, geteight, if size havent changed, only repaint and not relayout
}
}
@@ -942,7 +942,7 @@ void AnimationContent::movieUpdated(const TQRect&)
void AnimationContent::movieResized(const TQSize&)
{
- note()->requestRetqlayout(); // ?
+ note()->requestRelayout(); // ?
}
/** When a user drop a .gif file, for instance, we don't know if it is an image